/**
  *  \file client/tiles/taskmsgtile.cc
  *  \brief Class WTaskMessageTile
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/taskmsgtile.h"
#include "util/nls.h"
#include "int/notify.h"
#include "ui/richtext.h"
#include "client/screens/taskscreen.h"
#include "ui/richdocument.h"

WTaskMessageTile::WTaskMessageTile(GfxPoint pt)
    : WTile(pt),
      atsel(0),
      conn_task_changed(),
      buttonWidth(0)
{ }

void
WTaskMessageTile::initTask(WAutoTaskObjectSelection* atsel, int buttonWidth)
{
    // Remember it
    this->atsel = atsel;
    this->buttonWidth = buttonWidth;

    // Hook the event
    if (atsel) {
        conn_task_changed = atsel->sig_task_changed.add(this, &WTaskMessageTile::updateTask);
    }
}

void
WTaskMessageTile::updateTask()
{
    // Update content
    const IntNotificationMessage* msg = atsel ? atsel->getNotificationMessage() : 0;
    if (msg != 0 && !msg->isConfirmed()) {
        if (btn_confirm.get() == 0) {
            btn_confirm.reset(new UIButton(2000, UIKeyString(_("M - Confirm"))));
            btn_confirm->addCall(this, &WTaskMessageTile::onConfirm);
            addChildWidget(*btn_confirm, 0);
        }

        GfxRect area = getInnerSize(5, 5);
        UIWidget::LayoutInfo info;
        btn_confirm->getLayoutInfo(info);
        btn_confirm->setExtent(GfxRect(extent.x + area.x + area.w - buttonWidth - info.pref_size.x,
                                       extent.y + area.y + area.h               - info.pref_size.y,
                                       info.pref_size.x,
                                       info.pref_size.y));
    } else {
        btn_confirm.reset();
    }

    // Redraw remainder
    drawWidget();
}

bool
WTaskMessageTile::drawTask(GfxCanvas& can)
{
    const IntNotificationMessage* msg = atsel->getNotificationMessage();
    if (msg != 0 && !msg->isConfirmed()) {
        // Prepare drawing
        GfxRect area = getInnerSize(5, 5);
        RichDocument doc;
        doc.setPageWidth(area.w - buttonWidth);

        // Draw notification message
        doc.add(RichText(UIColor::tc_Heading, _("Notification")).withAttribute(RichTextStyleAttribute::Big));
        doc.addNewline();
        doc.add(msg->getBody());
        doc.addNewline();

        // Finish
        doc.finish();

        GfxContext ctx;
        ctx.useCanvas(can);
        ctx.useColorScheme(getSkin());
        drawBackground(ctx, GfxRect(area.x, area.y, area.w - buttonWidth, area.h));
        doc.draw(ctx, area, 0);
        return true;
    } else {
        return false;
    }
}

void
WTaskMessageTile::onConfirm()
{
    IntNotificationMessage* msg = atsel ? atsel->getNotificationMessage() : 0;
    if (msg != 0 && !msg->isConfirmed()) {
        msg->setConfirmed(true);
        updateTask();
    }
}
