/**
  *  \file client/widgets/simlist.h
  *  \brief Class WSimList
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_SIMLIST_H
#define PCC_V2_CLIENT_WIDGETS_SIMLIST_H

#include "ui/listbox.h"
#include "cpluslib/sigslot.h"
#include "cpluslib/string.h"

class GSimState;
class GSimShip;
class GSimulatorGameInterface;

/** List of battle participants. */
class WSimList : public UIListbox {
 public:
    WSimList(GSimulatorGameInterface& game_if, GSimState& state, bool with_planet);
    ~WSimList();
    void drawPart(GfxCanvas& can, int from, int to);

    GSimState& getSimState()
        { return state; }

    GSimulatorGameInterface& game()
        { return game_if; }

    GSimShip* getCurrentShip();

 private:
    void updateCount();
    void onShipChanged(int index);
    void onPlanetChanged();
    void onStructureChanged();

    GSimState& state;
    GSimulatorGameInterface& game_if;
    const bool with_planet;
    SignalConnection conn_ship_changed;
    SignalConnection conn_planet_changed;
    SignalConnection conn_structure_changed;
};

string_t getShipName(const GSimShip& sh);
string_t getPlanetName(GSimulatorGameInterface& game_if, const GSimState& st);

#endif
