/**
  *  \file flak/vis-sprites.h
  *  \brief Simple Visualisation Sprites
  *
  *  These sprites are shared between different visualisation modes.
  *
  *  (c) 2001-2017 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_FLAK_VIS_SPRITES_H
#define PCC_V2_FLAK_VIS_SPRITES_H

#include "flak/vis.h"
#include "gfx/sprite3d.h"
#include "client/vcranim.h"
#include "cpluslib/sigslot.h"

/// Explosion sprite.
class FlakExplSprite : public VcrExplSprite {
    FlakFancyVisualizer& vis;
    FlakPos p;
 public:
    FlakExplSprite(FlakPos p, FlakFancyVisualizer& vis, int size, int speed);
    ~FlakExplSprite();
    void tick();
};

/// Simple object sprite.
class FlakSimpleObjectSprite : public GfxSprite3D {
    enum {
        FIGHTER_RADIUS = 2,
        TORP_RADIUS    = 3
    };

    FlakFancyVisualizer& vis;
    FlakObject& obj;

    /** Constructor.
        \param pos screen position
        \param vis visualizer
        \param obj object to display */
    FlakSimpleObjectSprite(const FlakScreenArea& pos, FlakFancyVisualizer& vis, FlakObject& obj)
        : GfxSprite3D(pos, pos.z, vis.getObjectLayer(obj)), vis(vis), obj(obj)
        { }
    ~FlakSimpleObjectSprite();
 public:
    void draw(GfxCanvas& can);
    void tick();
    static FlakSimpleObjectSprite* create(FlakFancyVisualizer& vis, FlakObject& obj);
};

/// Simple ship sprite.
class FlakSimpleShipSprite : public GfxSprite3D {
    enum {
        SHIP_RADIUS = 5
    };

    FlakFancyVisualizer& vis;
    FlakFancyVisualizer::ship_t ship;
 public:
    FlakSimpleShipSprite(FlakFancyVisualizer& vis, FlakFancyVisualizer::ship_t ship)
        : GfxSprite3D(GfxRect(0, 0, 2*SHIP_RADIUS+1, 2*SHIP_RADIUS+1),
                      0, FlakFancyVisualizer::layer_Ships),
        vis(vis), ship(ship)
        { tick(); }
    void tick();
    void draw(GfxCanvas& can);
};

/// Simple beam sprite.
class FlakBeamSprite : public GfxSprite3D {
    const FlakPos start, end;
    FlakScreenPos spos, epos;
    FlakFancyVisualizer& vis;
    int status;
 public:
    FlakBeamSprite(FlakPos start, FlakPos end, FlakFancyVisualizer& vis);
    ~FlakBeamSprite();
    void tick();
    void draw(GfxCanvas& can);
};

#endif
